# Lyft Bike Share Data

Python client for Lyft bike share data.

## Features 

- Support for [cities](https://www.lyft.com/bikes#cities) with Lyft bike share
- [Historical trips](https://wd60622.github.io/lyft-bikes/examples/historical-trips/)
- Live station and bike / scooter availability
- [Applying pricing to trips](https://wd60622.github.io/lyft-bikes/examples/new-pricing/)
    - Unlock Fees
    - Minute Rates

## Installation 

Install from `pip` 

```shell 
$ pip install lyft-bikes
```

## Documentation

The documentation is hosted on [GitHub Pages](https://wd60622.github.io/lyft-bikes/).

## Development

The development environment was created with [`poetry`](https://python-poetry.org/docs/). The `pyproject.toml` file is the main configuration file for the project.

```bash
poetry install . 
```

## Contributing

If you would like to contribute or find some issue in the code, please [open an Issue](https://github.com/wd60622/divvy/issues/new) or a PR on GitHub. Thanks!